@@ -1,9 +1,9 @@
 #include "xdo_cmd.h"
 
-int cmd_getactivewindow(int argc, char **args) {
-  Window wid = 0;
+int cmd_getactivewindow(context_t *context) {
+  Window window = 0;
   int ret;
-  char *cmd = *args;
+  char *cmd = context->argv[0];
 
   int c;
   static struct option longopts[] = {
@@ -13,10 +13,12 @@ int cmd_getactivewindow(int argc, char **args) {
   static const char *usage = "Usage: %s\n";
   int option_index;
 
-  while ((c = getopt_long_only(argc, args, "h", longopts, &option_index)) != -1) {
+  while ((c = getopt_long_only(context->argc, context->argv, "+h",
+                               longopts, &option_index)) != -1) {
     switch (c) {
       case 'h':
         printf(usage, cmd);
+        consume_args(context, context->argc);
         return EXIT_SUCCESS;
         break;
       default:
@@ -25,20 +27,18 @@ int cmd_getactivewindow(int argc, char **args) {
     }
   }
 
-  argc -= optind;
-  args += optind;
+  consume_args(context, optind);
 
-  if (argc != 0) {
-    fprintf(stderr, usage, cmd);
-    return 1;
-  }
-
-  ret = xdo_window_get_active(xdo, &wid);
+  ret = xdo_window_get_active(context->xdo, &window);
 
   if (ret) {
     fprintf(stderr, "xdo_get_active_window reported an error\n");
   } else {
-    window_print(wid);
+    /* only print if we're the last command */
+    if (context->argc == 0) {
+      window_print(window);
+    }
+    window_save(context, window);
   }
 
   return ret;
