@@ -8,7 +8,8 @@ if ! which $XSERVERNAME > /dev/null 2>&1 ; then
   exit 1
 fi
 
-if [ ! -z "$WMNAME" ] && ! which $WMNAME > /dev/null 2>&1 ; then
+if [ ! -z "$WMNAME" -a "$WMNAME" != "none" ] \
+   && ! which $WMNAME > /dev/null 2>&1 ; then
   echo "Can't find $WMNAME, skipping..." >&2
   exit 1
 fi
