@@ -39,11 +39,22 @@ int xdo_window_search(const xdo_t *xdo, const xdo_search_t *search,
 
   /* TODO(sissel): Support multiple screens */
   if (search->searchmask & SEARCH_SCREEN) {
+    ncandidate_windows = candidate_window_list_size = 1;
+    candidate_window_list = calloc(sizeof(Window), candidate_window_list_size);
+    candidate_window_list[0] = RootWindow(xdo->xdpy, search->screen);
     _xdo_get_child_windows(xdo, RootWindow(xdo->xdpy, search->screen), search->max_depth,
                            &candidate_window_list, &ncandidate_windows,
                            &candidate_window_list_size);
   } else {
     const int screencount = ScreenCount(xdo->xdpy);
+    ncandidate_windows = candidate_window_list_size = screencount;
+    candidate_window_list = calloc(sizeof(Window), candidate_window_list_size);
+
+    /* TODO(sissel): Refactor these loops into one loop */
+    for (i = 0; i < screencount; i++) {
+      candidate_window_list[i] = RootWindow(xdo->xdpy, i);
+    }
+
     for (i = 0; i < screencount; i++) {
       _xdo_get_child_windows(xdo, RootWindow(xdo->xdpy, i), search->max_depth,
                              &candidate_window_list, &ncandidate_windows,
@@ -103,13 +114,15 @@ static void _xdo_get_child_windows(const xdo_t *xdo, Window window,
 
   for (i = 0; i < nchildren; i++) {
     Window w = children[i];
-    (*candidate_window_list)[*ncandidate_windows] = w;
-    *ncandidate_windows += 1;
+
     if (*ncandidate_windows == *window_list_size) {
       *window_list_size *= 2;
       *candidate_window_list = realloc(*candidate_window_list,
                                    *window_list_size * sizeof(Window));
     }
+
+    (*candidate_window_list)[*ncandidate_windows] = w;
+    *ncandidate_windows += 1;
     _xdo_get_child_windows(xdo, w, max_depth - 1, candidate_window_list,
                            ncandidate_windows, window_list_size);
   }
@@ -136,15 +149,22 @@ static int _xdo_window_match_name(const xdo_t *xdo, Window window, regex_t *re)
 
   XGetWMName(xdo->xdpy, window, &tp);
   if (tp.nitems > 0) {
-    XmbTextPropertyToTextList(xdo->xdpy, &tp, &list, &count);
+    //XmbTextPropertyToTextList(xdo->xdpy, &tp, &list, &count);
+    Xutf8TextPropertyToTextList(xdo->xdpy, &tp, &list, &count);
     for (i = 0; i < count; i++) {
-      //printf("%d: title '%s'\n", window, list[i]);
       if (regexec(re, list[i], 0, NULL, 0) == 0) {
         XFreeStringList(list);
         XFree(tp.value);
         return True;
       }
     }
+  } else {
+    /* Treat windows with no names as empty strings */
+    if (regexec(re, "", 0, NULL, 0) == 0) {
+      XFreeStringList(list);
+      XFree(tp.value);
+      return True;
+    }
   }
   XFreeStringList(list);
   XFree(tp.value);
@@ -165,6 +185,11 @@ static int _xdo_window_match_class(const xdo_t *xdo, Window window, regex_t *re)
     }
     XFree(classhint.res_name);
     XFree(classhint.res_class);
+  } else {
+    /* Treat windows with no class as empty strings */
+    if (regexec(re, "", 0, NULL, 0) == 0) {
+      return True;
+    }
   }
   return False;
 }
@@ -182,6 +207,11 @@ static int _xdo_window_match_classname(const xdo_t *xdo, Window window, regex_t
     }
     XFree(classhint.res_name);
     XFree(classhint.res_class);
+  } else {
+    /* Treat windows with no class name as empty strings */
+    if (regexec(re, "", 0, NULL, 0) == 0) {
+      return True;
+    }
   }
   return False;
 }
@@ -221,7 +251,8 @@ static int _xdo_is_window_visible(const xdo_t *xdo, Window wid) {
   return True;
 }
 
-static int check_window_match(const xdo_t *xdo, Window wid, const xdo_search_t *search) {
+static int check_window_match(const xdo_t *xdo, Window wid,
+                              const xdo_search_t *search) {
   regex_t title_re;
   regex_t class_re;
   regex_t classname_re;
